API reference
=============

The ``pygranta`` metapackage does not have an API. The only information that you can
obtain specific to this package is the version.

To obtain the metapackage version, use this code:

.. code-block:: pycon

    >>> from pygranta import __version__
    >>> __version__

    '2023.2.0'

Each PyGranta package has its own "API reference" documentation section.

**************************
PyGranta API documentation
**************************

.. grid:: 3

    .. grid-item-card:: PyGranta BoM Analytics :material-regular:`science` :material-regular:`eco`
      :padding: 2 2 2 2
      :link: https://bomanalytics.grantami.docs.pyansys.com/version/stable/api/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta RecordLists :material-regular:`list`
      :padding: 2 2 2 2
      :link: https://recordlists.grantami.docs.pyansys.com/version/stable/api/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta JobQueue :material-regular:`work_history`
      :padding: 2 2 2 2
      :link: https://jobqueue.grantami.docs.pyansys.com/version/stable/api/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta System :material-regular:`settings`
      :padding: 2 2 2 2
      :link: https://system.grantami.docs.pyansys.com/version/stable/api/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta Data Flow Extensions :material-outlined:`fork_right`
      :padding: 2 2 2 2
      :link: https://dataflow-extensions.grantami.docs.pyansys.com/version/stable/api/index.html
      :class-title: pyansys-card-title
